Security Advisories (2)
CVE-2024-58134 (2025-05-03)

Mojolicious versions from 0.999922 for Perl uses a hard coded string, or the application's class name, as a HMAC session secret by default. These predictable default secrets can be exploited to forge session cookies. An attacker who knows or guesses the secret could compute valid HMAC signatures for the session cookie, allowing them to tamper with or hijack another user's session.

CVE-2024-58135 (2025-05-03)

Mojolicious versions from 7.28 for Perl may generate weak HMAC session secrets. When creating a default app with the "mojo generate app" tool, a weak secret is written to the application's configuration file using the insecure rand() function, and used for authenticating and protecting the integrity of the application's sessions. This may allow an attacker to brute force the application's session keys.

NAME

Mojo::UserAgent::Server - Application server

SYNOPSIS

use Mojo::UserAgent::Server;

my $server = Mojo::UserAgent::Server->new;
say $server->url;

DESCRIPTION

Mojo::UserAgent::Server is an embedded web server based on Mojo::Server::Daemon that processes requests for Mojo::UserAgent.

ATTRIBUTES

Mojo::UserAgent::Server implements the following attributes.

ioloop

my $loop = $server->ioloop;
$server  = $server->ioloop(Mojo::IOLoop->new);

Event loop object to use for I/O operations, defaults to the global Mojo::IOLoop singleton.

METHODS

Mojo::UserAgent::Server inherits all methods from Mojo::Base and implements the following new ones.

app

my $app = Mojo::UserAgent::Server->app;
          Mojo::UserAgent::Server->app(Mojolicious->new);
my $app = $server->app;
$server = $server->app(Mojolicious->new);

Application this server handles, instance specific applications override the global default.

# Change application behavior
$server->app->defaults(testing => 'oh yea!');

nb_url

my $url = $server->nb_url;
my $url = $server->nb_url('http');
my $url = $server->nb_url('https');

Get absolute Mojo::URL object for server processing non-blocking requests with "app" and switch protocol if necessary.

restart

$server->restart;

Restart server with new port.

url

my $url = $server->url;
my $url = $server->url('http');
my $url = $server->url('https');

Get absolute Mojo::URL object for server processing blocking requests with "app" and switch protocol if necessary.

SEE ALSO

Mojolicious, Mojolicious::Guides, https://mojolicious.org.